==> haskell-pandoc-lua-engine-0.2.1.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.2.1.3
visibility:           public
id:                   pandoc-lua-engine-0.2.1.3-DoinP09exwiG36M4OSXaea
key:                  pandoc-lua-engine-0.2.1.3-DoinP09exwiG36M4OSXaea
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  bb8887e540a17d292548ffbe52bfa139
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.3-DoinP09exwiG36M4OSXaea
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig base-4.17.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-BwKVMTmOKD2JR9bxTL6xTn
    containers-0.6.7 data-default-0.7.1.2-1WYBg9tpZep2i2jrc12PQs
    doclayout-0.4.0.1-5cBRrc95Bng9ZpJaQ2c6jD
    doctemplates-0.11.0.1-AMBMd1RJLs26yzcfwlu8Fz exceptions-0.10.5
    hslua-2.3.0-AQ372WB68rE8X4AEHVaoWD
    hslua-module-doclayout-1.1.1.1-KybOvVYqdLk6g8halez2p1
    hslua-module-path-1.1.1-1uGsEVN6DNkFd9ve5gVpDD
    hslua-module-system-1.1.2-Bl54tj2PQGM8mmUFr2rt6b
    hslua-module-text-1.1.0.1-5QNeOMk3IYHEkkguT2mnqK
    hslua-module-version-1.1.1-64Ct3jAwTCjBh1LMXPOaD7
    hslua-module-zip-1.1.3-I6bzphX6l5OwDgDeXXUB4
    hslua-repl-0.1.2-4zhqdYbIHdAERMEEHtOlVU
    lpeg-1.1.0-7Rbw5iz5nh6EwApSZMGPpa mtl-2.2.2
    pandoc-3.2-ENWCdHA16PlEL5OfVQPDzb
    pandoc-lua-marshal-0.2.8-AhFRgSUi36a18RYmeszjlb
    pandoc-types-1.23.1-2jedVNew2xB36sQgMgJsQb parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-engine-0.2.1.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.2.1.3
visibility:           public
id:                   pandoc-lua-engine-0.2.1.3-5ZIGYTkvK0YAwY8f3tNs9S
key:                  pandoc-lua-engine-0.2.1.3-5ZIGYTkvK0YAwY8f3tNs9S
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  f87eb04b29a330d5e7731d9fea9c980a
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.3-5ZIGYTkvK0YAwY8f3tNs9S
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    aeson-2.1.2.1-LTS2NYlb1uX1OFFp0jy4wh base-4.17.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-BRuZGRodmX76w6nvtGgAGK
    containers-0.6.7 data-default-0.7.1.2-1WYBg9tpZep2i2jrc12PQs
    doclayout-0.4.0.1-79th7mGFDtZ3rT3aQPy9xM
    doctemplates-0.11.0.1-GG1yLRsXnB4AMJ2jnfGF1 exceptions-0.10.5
    hslua-2.3.0-KP35kPBnYNyHeWZwDYKanY
    hslua-module-doclayout-1.1.1.1-KQ1hQLnunsPcz0Kqvrzfh
    hslua-module-path-1.1.1-CrYdSEvQKPJJXosYHXoTxb
    hslua-module-system-1.1.2-DpCLqe6Et5HHlSP62lfeOU
    hslua-module-text-1.1.0.1-5SFwuUTLiAh8KkUroECUdT
    hslua-module-version-1.1.1-8TqR6a28kJ9EhabRtawtWS
    hslua-module-zip-1.1.3-JpCFmsvYPPHL3mU1J64kPs
    hslua-repl-0.1.2-IC11spllLrXDXuwvuR3rVV
    lpeg-1.1.0-HUvFxN4U4b0Azk0Fll2nYU mtl-2.2.2
    pandoc-3.2-DErrM0WsfVm5WvE6Gbzdnw
    pandoc-lua-marshal-0.2.8-1Dn9WYQJGopK0yh4VRpZb0
    pandoc-types-1.23.1-K1PizIj5kzwKTWPUJjx6Zn parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
